@@ -32,8 +32,8 @@ struct _tagCharConv{
 
 int CharsetConvert(CharConv *ctx, struct lines *l);
 void ConvertClose(CharConv *ctx);
-void SetupEncoding(CharConv *ctx, DfStr *src, DfStr *dst);
-
-void SetupXXXX(CharConv *ctx);
+void SetupEncoding(CharConv *ctx);
+void SetupConvBuffer(CharConv *ctx, DfStr *src, DfStr *dst);
 void SetupNewline(CharConv *ctx);
+void ResetCtx(CharConv *ctx, DfStr *src, int offset, DfStr *dst);
 
