@@ -24,6 +24,7 @@
 #include "dialog.h"
 #include "task.h"
 #include "cmd.h"
+#include "chcode.h"
 #include "xutil.h"
 #include "misc.h"
 #include "mem.h"
@@ -495,6 +496,11 @@ DfCmdKey c_strL[] ={
   0
 };
 
+DfCmdKey c_strV[] ={
+  XK_v,
+  0
+};
+
 DfCmdKey c_strSlash[] ={
   XK_slash,
   0
@@ -646,6 +652,7 @@ const DfCmdStr FL_DefaultCmdTab[] = {
   {c_strColon,      CMD_FILER,  CLEARMARK},
   {c_strOpen,       CMD_ANY,    OPEN},
   {c_strOpen,       CMD_VIEWER, CLOSE},
+  {c_strV,          CMD_VIEWER, CLOSE},
   {c_strSplitH,     CMD_ANY,    SPLIT_H},
   {c_strSplitV,     CMD_ANY,    SPLIT_V},
   {c_strWN,         CMD_ANY,    NEXTFRAME},
@@ -667,6 +674,7 @@ const DfCmdStr FL_DefaultCmdTab[] = {
   {c_strF,          CMD_FILER,  FILTER},
   {c_strCtrlF,      CMD_FILER,  IFILTER},
   {c_strL,          CMD_FILER,  GOTO},
+  {c_strV,          CMD_FILER,  VIEW},
   {c_strL,          CMD_VIEWER, CHNEWLINE},
   {c_strI,          CMD_ANY,    INFO},
   {c_strF5,         CMD_FILER,  RELOAD},
@@ -779,6 +787,7 @@ static void AppInitialize(XtAppContext *app, Widget w)
   v_gid = getgid();
   v_uid = getuid();
   vInUTF8 = InUTF8();
+  chcode_init();
 }
 
 int ReloadConfig(void)
@@ -842,7 +851,7 @@ static void wndKeyPressProc(Widget w, XtPointer p, XEvent *event, Boolean *cont)
     mod_keys |= DFMOD_ALT;
     break;
   default:
-    St_SetMsg(w, NULL);
+    St_ClearMsg(w);
     buf = dfx->active;
     buf->v->keybd_event(w, buf, k, ch[0], cont);
   }
