@@ -28,6 +28,7 @@
 #include "dialog.h"
 #include "task.h"
 #include "cmd.h"
+#include "chcode.h"
 #include "xutil.h"
 #include "misc.h"
 #include "mem.h"
@@ -431,14 +432,24 @@ static int FL_Process(Widget w, void *ptr, const DfCmdStr *c, const char **argv)
     break;
   case HORIZ_LEFT:
     if(vnHoriz){
-      vnHoriz--;
+      char *f = list->files[list->b.nCur]->name;
+      int n = (*dfx_mbbacklen)(f + vnHoriz, vnHoriz);
+      if(vnHoriz < n){
+        vnHoriz = 0;
+      }else{
+        vnHoriz -= n;
+      }
       drawSingleItemDI(w, list, list->b.nCur);
     }
     break;
   case HORIZ_RIGHT:
-    if(vnHoriz + 1 < strlen(list->files[list->b.nCur]->name)){
-      vnHoriz++;
-      drawSingleItemDI(w, list, list->b.nCur);
+    {
+      char *f = list->files[list->b.nCur]->name;
+      int n = (*dfx_mblen)(f[vnHoriz]);
+      if(vnHoriz + n < strlen(f)){
+        vnHoriz += n;
+        drawSingleItemDI(w, list, list->b.nCur);
+      }
     }
     break;
   case FILTER:
@@ -742,7 +753,7 @@ static void drawSingleItem(void *p, struct DfDrawInfo *di, int cur)
   char *pszName;
   int len;
 #if DRAW_SIZE
-  char buf[32];
+  char buf[64];
   int cx;
   int x;
 #endif
@@ -2101,7 +2112,7 @@ NEXT:
 
 static task_result isearchDone(DfTask *t)
 {
-  St_SetMsg(t->w, NULL);
+  St_ClearMsg(t->w);
   return TASK_FREE;
 }
 
@@ -2200,7 +2211,7 @@ static task_result execInvoke(DfTask *t)
 
   cmd = Str_Get(&t->input);
 
-  St_SetMsg(t->w, NULL);
+  St_ClearMsg(t->w);
   if(cmd && cmd[0]){
     fail = DfxExec(t->w, t->owner, Str_Get(&t->cwd), cmd, &builtin);
     if(fail == 0 && builtin == 0){
