@@ -331,7 +331,7 @@ task_result commonThreadedInvoke(DfTask *t)
 {
 
   pthread_create(&t->t_info, NULL, operation_thread, t);
-  St_SetMsg(t->w, NULL);
+  St_ClearMsg(t->w);
 
   return TASK_LEAVE;
 }
@@ -391,7 +391,11 @@ task_result commonDone(DfTask *t)
       msg = strerror(t->err);
     }
   }
-  St_SetMsg(t->w, msg);
+  if(msg){
+    St_SetMsg(t->w, msg);
+  }else{
+    St_ClearMsg(t->w);
+  }
 
   if(!t->update){
     return TASK_FREE;
@@ -859,7 +863,7 @@ void taskCbInvoke(DfTask *t)
     if(t->v->done){
       (*t->v->done)(t);
     }
-    St_SetMsg(t->w, NULL);
+    St_ClearMsg(t->w);
     FreeTask(t);
   }
 }
